@@ -1,10 +1,10 @@
 import mvlearn.embed
 import mvlearn.cluster
 import mvlearn.construct
-import mvlearn.cotraining
+import mvlearn.semi_supervised
 import mvlearn.datasets
 import mvlearn.utils
-import mvlearn.factorization
+import mvlearn.decomposition
 import mvlearn.plotting
 
-__version__ = "0.2.0"
+__version__ = "0.3.0"
